src/*
1
4
Done processing src/pptable.cpp
Done processing src/pptable.h
Total errors found: 675

src/pptable.cpp:0:  No copyright message found.  You should have a line: "Copyright [year] <Copyright Owner>"  [legal/copyright] [5]
src/pptable.cpp:1:  Include the directory when naming header files  [build/include_subdir] [4]
src/pptable.cpp:6:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:7:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:8:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:8:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:10:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:11:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:11:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:12:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:16:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:17:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:18:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:18:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/pptable.cpp:19:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:19:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/pptable.cpp:20:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:20:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/pptable.cpp:21:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:23:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:24:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:24:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/pptable.cpp:25:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:25:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/pptable.cpp:26:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:27:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:30:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:31:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:32:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:33:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:34:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:35:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:37:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:37:  Extra space after ( in function call  [whitespace/parens] [4]
src/pptable.cpp:37:  Extra space before )  [whitespace/parens] [2]
src/pptable.cpp:39:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:39:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:39:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:40:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:41:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:42:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:43:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:44:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:45:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:46:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:48:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:49:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:49:  Extra space after ( in function call  [whitespace/parens] [4]
src/pptable.cpp:50:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:51:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:53:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:54:  Redundant blank line at the start of a code block should be deleted.  [whitespace/blank_line] [2]
src/pptable.cpp:55:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:56:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:57:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:59:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:59:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:59:  Missing space before ( in if(  [whitespace/parens] [5]
src/pptable.cpp:60:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:61:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:63:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:64:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:65:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:66:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:67:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/pptable.cpp:68:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:69:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:70:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:74:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:75:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:76:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:77:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:78:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:79:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:80:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:80:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:80:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:81:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:82:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:83:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:84:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:85:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:86:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:87:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:89:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:90:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:90:  Extra space after ( in function call  [whitespace/parens] [4]
src/pptable.cpp:91:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:92:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:94:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:95:  Redundant blank line at the start of a code block should be deleted.  [whitespace/blank_line] [2]
src/pptable.cpp:96:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:97:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:98:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:100:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:100:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:100:  Missing space before ( in if(  [whitespace/parens] [5]
src/pptable.cpp:101:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:102:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:104:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:105:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:106:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:107:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:108:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/pptable.cpp:109:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:110:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:111:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:115:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:116:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:117:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:118:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:119:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:120:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:120:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:121:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:122:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:123:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:124:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:125:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:126:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:127:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:128:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:129:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:131:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:132:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:132:  Extra space after ( in function call  [whitespace/parens] [4]
src/pptable.cpp:133:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:135:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:136:  Redundant blank line at the start of a code block should be deleted.  [whitespace/blank_line] [2]
src/pptable.cpp:137:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:138:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:139:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:141:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:142:  Redundant blank line at the start of a code block should be deleted.  [whitespace/blank_line] [2]
src/pptable.cpp:143:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:144:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:145:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:146:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/pptable.cpp:147:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:148:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:149:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:153:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:153:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:155:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:156:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:158:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:159:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:159:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:159:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:160:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:160:  Using C-style cast.  Use static_cast<int>(...) instead  [readability/casting] [4]
src/pptable.cpp:162:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:164:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:164:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:165:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:166:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:167:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:167:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:168:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:169:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:170:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:170:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:170:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/pptable.cpp:171:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:173:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:177:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:179:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:180:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:181:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:182:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:183:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:184:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:184:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:184:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:185:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:186:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:187:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:188:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:189:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:191:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:192:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:192:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:193:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:198:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:199:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:200:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:201:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:202:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:203:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:203:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:203:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:204:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:205:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:206:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:207:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:208:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:209:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:210:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:211:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:215:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:216:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:218:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:219:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:219:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:220:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:222:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:223:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:224:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:226:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:227:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:228:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:229:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:230:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:231:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:232:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:233:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:233:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:233:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:234:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:234:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:234:  Missing space before {  [whitespace/braces] [5]
src/pptable.cpp:235:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:236:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:237:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:238:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:240:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:240:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:240:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:241:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:242:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:243:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:244:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:245:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:246:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:247:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:248:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:248:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:248:  Extra space after ( in function call  [whitespace/parens] [4]
src/pptable.cpp:249:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:251:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:252:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:253:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:254:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:255:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:256:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:258:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:259:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:260:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:261:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:262:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:263:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:264:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:266:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:267:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:268:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:269:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:272:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:273:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:274:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:275:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:276:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:278:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:279:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:280:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:280:  Mismatching spaces inside () in if  [whitespace/parens] [5]
src/pptable.cpp:281:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:282:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:284:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:285:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:287:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:287:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:287:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:288:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:289:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:291:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:292:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:293:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:295:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:295:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:295:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:296:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:297:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:298:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:299:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:300:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:300:  Extra space for operator  --;  [whitespace/operators] [4]
src/pptable.cpp:301:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:302:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:303:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:304:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:305:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:306:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:307:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:308:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:309:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:310:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:311:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:312:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:313:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:314:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:315:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:316:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:317:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:318:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:319:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:320:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:321:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:322:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:323:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:324:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:325:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:328:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:329:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:330:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:330:  Using C-style cast.  Use static_cast<int>(...) instead  [readability/casting] [4]
src/pptable.cpp:331:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:332:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:334:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:335:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:336:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:336:  Mismatching spaces inside () in if  [whitespace/parens] [5]
src/pptable.cpp:337:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:338:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:339:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:341:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:341:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:341:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:341:  Using C-style cast.  Use static_cast<size_t>(...) instead  [readability/casting] [4]
src/pptable.cpp:342:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:343:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:345:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:346:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:347:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:349:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:349:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:349:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:350:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:351:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:352:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:353:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:354:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:354:  Extra space for operator  --;  [whitespace/operators] [4]
src/pptable.cpp:355:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:356:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:357:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:358:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:359:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:360:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:361:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:362:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:363:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:364:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:365:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:366:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:367:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:368:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:369:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:370:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:371:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:372:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:373:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:374:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:375:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:376:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:377:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:378:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:379:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:383:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:384:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:385:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:387:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:387:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:387:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:388:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:389:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:390:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:390:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:391:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:392:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:393:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:393:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:394:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:395:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:396:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:396:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:397:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:398:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:402:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:403:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:404:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:405:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:406:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:406:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:406:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:407:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:408:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:409:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:410:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:411:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:412:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:413:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:414:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:420:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:424:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:428:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:429:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:430:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:431:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:432:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:436:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:437:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:438:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:439:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:440:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:444:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:445:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:446:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:447:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:448:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:450:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:454:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:455:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:456:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:458:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:459:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:460:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:461:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:462:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:463:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:463:  If an else has a brace on one side, it should have it on both  [readability/braces] [5]
src/pptable.cpp:464:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:465:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:466:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:466:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:467:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:468:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:469:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:473:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:474:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:475:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:476:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:477:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:481:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:482:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:483:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:484:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:485:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:489:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:490:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:491:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:495:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:496:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:497:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:498:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:499:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:500:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:501:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:502:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:502:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:503:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:504:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:504:  Missing space before {  [whitespace/braces] [5]
src/pptable.cpp:505:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:505:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.cpp:506:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:507:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:509:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:509:  Missing space before ( in if(  [whitespace/parens] [5]
src/pptable.cpp:510:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:512:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:513:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:514:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:515:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:515:  Use int16_t/int64_t/etc, rather than the C type long  [runtime/int] [4]
src/pptable.cpp:516:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:516:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:517:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:518:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:519:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:520:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:521:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:525:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:526:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:527:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:528:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:529:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:533:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:534:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:538:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:539:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:542:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:543:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:544:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:545:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:546:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:548:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:549:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:550:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:551:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:552:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:553:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:555:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:556:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:557:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:557:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:558:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:560:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:561:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:562:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:562:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:562:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:563:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:564:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:565:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:566:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:568:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:569:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:570:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:572:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:573:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:574:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:575:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:576:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:577:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:578:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:579:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:582:  Static/global string variables are not permitted.  [runtime/string] [4]
src/pptable.cpp:584:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:585:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:586:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:587:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:588:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:589:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:591:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:592:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:593:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:593:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:594:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:596:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:597:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:598:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:599:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:599:  Missing spaces around =  [whitespace/operators] [4]
src/pptable.cpp:599:  Missing spaces around <  [whitespace/operators] [3]
src/pptable.cpp:600:  Redundant blank line at the start of a code block should be deleted.  [whitespace/blank_line] [2]
src/pptable.cpp:602:  Using C-style cast.  Use static_cast<int>(...) instead  [readability/casting] [4]
src/pptable.cpp:602:  Never use sprintf. Use snprintf instead.  [runtime/printf] [5]
src/pptable.cpp:604:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:605:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:606:  Missing space before ( in while(  [whitespace/parens] [5]
src/pptable.cpp:607:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:609:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:612:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:614:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:615:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:616:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:617:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:619:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:619:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:620:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:622:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:623:  Redundant blank line at the start of a code block should be deleted.  [whitespace/blank_line] [2]
src/pptable.cpp:624:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:625:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:626:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:627:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:629:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:631:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:631:  Should have a space between // and comment  [whitespace/comments] [4]
src/pptable.cpp:632:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:632:  Should have a space between // and comment  [whitespace/comments] [4]
src/pptable.cpp:634:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:635:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:636:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:639:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.cpp:640:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.cpp:641:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:642:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:643:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:644:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:645:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:646:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:647:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:648:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:649:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:650:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:651:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:653:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:654:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:654:  Missing space before {  [whitespace/braces] [5]
src/pptable.cpp:655:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:656:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:657:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:659:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:660:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:661:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:662:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:663:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.cpp:526:  Add #include <map> for map<>  [build/include_what_you_use] [4]
src/pptable.cpp:592:  Add #include <vector> for vector<>  [build/include_what_you_use] [4]
src/pptable.cpp:602:  Add #include <cstdio> for sprintf  [build/include_what_you_use] [4]
src/pptable.cpp:648:  Add #include <string> for string  [build/include_what_you_use] [4]
src/pptable.h:0:  No copyright message found.  You should have a line: "Copyright [year] <Copyright Owner>"  [legal/copyright] [5]
src/pptable.h:1:  #ifndef header guard has wrong style, please use: SAMPLES_CODELITE_SAMPLE_SRC_PPTABLE_H_  [build/header_guard] [5]
src/pptable.h:131:  #endif line should be "#endif  // SAMPLES_CODELITE_SAMPLE_SRC_PPTABLE_H_"  [build/header_guard] [5]
src/pptable.h:6:  Found C system header after C++ system header. Should be: pptable.h, c system, c++ system, other.  [build/include_order] [4]
src/pptable.h:19:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/pptable.h:27:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:28:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:29:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:30:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:31:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:32:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:49:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.h:63:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.h:69:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:70:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:71:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:72:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:73:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:75:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:76:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:77:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:78:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:78:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.h:79:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:80:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:82:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:83:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:83:  Missing space before {  [whitespace/braces] [5]
src/pptable.h:85:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:86:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:86:  Missing space before {  [whitespace/braces] [5]
src/pptable.h:88:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:89:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:90:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:91:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:92:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:92:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.h:93:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:93:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/pptable.h:94:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:95:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:96:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:96:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.h:96:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/pptable.h:100:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/pptable.h:101:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:102:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:104:  public: should be indented +1 space inside class PPTable  [whitespace/indent] [3]
src/pptable.h:105:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:106:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:108:  private: should be indented +1 space inside class PPTable  [whitespace/indent] [3]
src/pptable.h:109:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:110:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:112:  public: should be indented +1 space inside class PPTable  [whitespace/indent] [3]
src/pptable.h:113:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:114:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:115:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:115:  Extra space before ( in function call  [whitespace/parens] [4]
src/pptable.h:116:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:117:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:118:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:119:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:120:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:121:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:123:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:124:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:125:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:126:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:126:  Line ends in whitespace.  Consider deleting these extra spaces.  [whitespace/end_of_line] [4]
src/pptable.h:127:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:128:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:129:  Tab found; better to use spaces  [whitespace/tab] [1]
src/pptable.h:131:  At least two spaces is best between code and comments  [whitespace/comments] [2]

