--recursive "--exclude=src/tr1/*" src
1
3
Done processing src/inspect/unnamed_namespace_check.hpp
Total errors found: 49

src/inspect/unnamed_namespace_check.hpp:0:  No #ifndef header guard found, suggested CPP variable is: SAMPLES_BOOST_SAMPLE_SRC_INSPECT_UNNAMED_NAMESPACE_CHECK_HPP_  [build/header_guard] [5]
src/inspect/unnamed_namespace_check.hpp:11:  Include the directory when naming header files  [build/include_subdir] [4]
src/inspect/unnamed_namespace_check.hpp:14:  Do not use unnamed namespaces in header files.  See https://google-styleguide.googlecode.com/svn/trunk/cppguide.xml#Namespaces for more information.  [build/namespaces_headers] [4]
src/inspect/unnamed_namespace_check.hpp:17:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:18:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/inspect/unnamed_namespace_check.hpp:19:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:21:  Anonymous namespace should be terminated with "// namespace"  [readability/namespace] [5]
src/inspect/unnamed_namespace_check.hpp:21:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/inspect/unnamed_namespace_check.hpp:26:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/inspect/unnamed_namespace_check.hpp:27:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:28:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:28:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/inspect/unnamed_namespace_check.hpp:29:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:29:  Weird number of spaces at line-start.  Are you using a 2-space indent?  [whitespace/indent] [3]
src/inspect/unnamed_namespace_check.hpp:30:  Weird number of spaces at line-start.  Are you using a 2-space indent?  [whitespace/indent] [3]
src/inspect/unnamed_namespace_check.hpp:30:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/inspect/unnamed_namespace_check.hpp:31:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:31:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:32:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/inspect/unnamed_namespace_check.hpp:32:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:32:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:33:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:33:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:34:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/inspect/unnamed_namespace_check.hpp:34:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:34:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:35:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:35:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:36:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:36:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:37:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:37:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:38:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:38:  Weird number of spaces at line-start.  Are you using a 2-space indent?  [whitespace/indent] [3]
src/inspect/unnamed_namespace_check.hpp:40:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:40:  Weird number of spaces at line-start.  Are you using a 2-space indent?  [whitespace/indent] [3]
src/inspect/unnamed_namespace_check.hpp:44:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:44:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/inspect/unnamed_namespace_check.hpp:48:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/inspect/unnamed_namespace_check.hpp:49:  Missing space before ( in for(  [whitespace/parens] [5]
src/inspect/unnamed_namespace_check.hpp:50:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/inspect/unnamed_namespace_check.hpp:54:  Extra space after ( in function call  [whitespace/parens] [4]
src/inspect/unnamed_namespace_check.hpp:54:  Extra space before )  [whitespace/parens] [2]
src/inspect/unnamed_namespace_check.hpp:57:  Redundant blank line at the end of a code block should be deleted.  [whitespace/blank_line] [3]
src/inspect/unnamed_namespace_check.hpp:58:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:59:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/inspect/unnamed_namespace_check.hpp:59:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/inspect/unnamed_namespace_check.hpp:60:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/inspect/unnamed_namespace_check.hpp:51:  Add #include <string> for string  [build/include_what_you_use] [4]

