--counting=toplevel --filter=-whitespace,-build/include_what_you_use src/*.cpp
1
7
Done processing src/sillycode.cpp
Category 'build' errors found: 5
Category 'legal' errors found: 1
Category 'readability' errors found: 4
Category 'runtime' errors found: 7
Total errors found: 17

src/sillycode.cpp:0:  No copyright message found.  You should have a line: "Copyright [year] <Copyright Owner>"  [legal/copyright] [5]
src/sillycode.cpp:1:  Include the directory when naming header files  [build/include_subdir] [4]
src/sillycode.cpp:2:  <ratio> is an unapproved C++11 header.  [build/c++11] [5]
src/sillycode.cpp:3:  Found C system header after other header. Should be: sillycode.h, c system, c++ system, other.  [build/include_order] [4]
src/sillycode.cpp:4:  Found C system header after other header. Should be: sillycode.h, c system, c++ system, other.  [build/include_order] [4]
src/sillycode.cpp:5:  Do not use namespace using-directives.  Use using-declarations instead.  [build/namespaces] [5]
src/sillycode.cpp:40:  If/else bodies with multiple statements require braces  [readability/braces] [4]
src/sillycode.cpp:66:  Single-parameter constructors should be marked explicit.  [runtime/explicit] [4]
src/sillycode.cpp:76:  Single-parameter constructors should be marked explicit.  [runtime/explicit] [4]
src/sillycode.cpp:85:  Constructors callable with one argument should be marked explicit.  [runtime/explicit] [4]
src/sillycode.cpp:171:  Do not use variable-length arrays.  Use an appropriately named ('k' followed by CamelCase) compile-time constant for the size.  [runtime/arrays] [1]
src/sillycode.cpp:178:  Static/global string variables are not permitted.  [runtime/string] [4]
src/sillycode.cpp:199:  If an else has a brace on one side, it should have it on both  [readability/braces] [5]
src/sillycode.cpp:208:  Static/global string variables are not permitted.  [runtime/string] [4]
src/sillycode.cpp:227:  Static/global string variables are not permitted.  [runtime/string] [4]
src/sillycode.cpp:228:  Using C-style cast.  Use reinterpret_cast<double*>(...) instead  [readability/casting] [4]
src/sillycode.cpp:243:  Using C-style cast.  Use reinterpret_cast<derived2*>(...) instead  [readability/casting] [4]

