src/*
1
6
Done processing src/chrome_content_renderer_client.cc
Done processing src/chrome_content_renderer_client.h
Done processing src/io_thread.cc
Done processing src/io_thread.h
Total errors found: 18

src/chrome_content_renderer_client.cc:303:  Do not indent within a namespace.  [whitespace/indent_namespace] [4]
src/chrome_content_renderer_client.cc:308:  Add #include <vector> for vector<>  [build/include_what_you_use] [4]
src/chrome_content_renderer_client.cc:1540:  Add #include <set> for set<>  [build/include_what_you_use] [4]
src/chrome_content_renderer_client.cc:1841:  Add #include <string> for string  [build/include_what_you_use] [4]
src/chrome_content_renderer_client.cc:5:  samples/chromium-sample/src/chrome_content_renderer_client.cc should include its header file samples/chromium-sample/src/chrome_content_renderer_client.h  [build/include] [5]
src/chrome_content_renderer_client.h:5:  #ifndef header guard has wrong style, please use: SAMPLES_CHROMIUM_SAMPLE_SRC_CHROME_CONTENT_RENDERER_CLIENT_H_  [build/header_guard] [5]
src/chrome_content_renderer_client.h:225:  #endif line should be "#endif  // SAMPLES_CHROMIUM_SAMPLE_SRC_CHROME_CONTENT_RENDERER_CLIENT_H_"  [build/header_guard] [5]
src/chrome_content_renderer_client.h:115:  Use int16_t/int64_t/etc, rather than the C type long  [runtime/int] [4]
src/chrome_content_renderer_client.h:117:  Use int16_t/int64_t/etc, rather than the C type long  [runtime/int] [4]
src/io_thread.cc:1148:  Closing ) should be moved to the previous line  [whitespace/parens] [2]
src/io_thread.cc:1547:  Missing space around colon in range-based for loop  [whitespace/forcolon] [2]
src/io_thread.cc:651:  Add #include <map> for map<>  [build/include_what_you_use] [4]
src/io_thread.cc:1546:  Add #include <unordered_set> for unordered_set<>  [build/include_what_you_use] [4]
src/io_thread.cc:1609:  Add #include <string> for string  [build/include_what_you_use] [4]
src/io_thread.cc:1731:  Add #include <memory> for unique_ptr<>  [build/include_what_you_use] [4]
src/io_thread.cc:5:  samples/chromium-sample/src/io_thread.cc should include its header file samples/chromium-sample/src/io_thread.h  [build/include] [5]
src/io_thread.h:5:  #ifndef header guard has wrong style, please use: SAMPLES_CHROMIUM_SAMPLE_SRC_IO_THREAD_H_  [build/header_guard] [5]
src/io_thread.h:565:  #endif line should be "#endif  // SAMPLES_CHROMIUM_SAMPLE_SRC_IO_THREAD_H_"  [build/header_guard] [5]

