src/*
1
5
Done processing src/libvlc.c
Done processing src/libvlc.h
Done processing src/missing.c
Total errors found: 599

src/libvlc.c:41:  Found C system header after other header. Should be: libvlc.h, c system, c++ system, other.  [build/include_order] [4]
src/libvlc.c:47:  Found C system header after other header. Should be: libvlc.h, c system, c++ system, other.  [build/include_order] [4]
src/libvlc.c:48:  Found C system header after other header. Should be: libvlc.h, c system, c++ system, other.  [build/include_order] [4]
src/libvlc.c:49:  Found C system header after other header. Should be: libvlc.h, c system, c++ system, other.  [build/include_order] [4]
src/libvlc.c:50:  Found C system header after other header. Should be: libvlc.h, c system, c++ system, other.  [build/include_order] [4]
src/libvlc.c:71:  Include the directory when naming header files  [build/include_subdir] [4]
src/libvlc.c:75:  Found C system header after other header. Should be: libvlc.h, c system, c++ system, other.  [build/include_order] [4]
src/libvlc.c:86:  Extra space before [  [whitespace/braces] [5]
src/libvlc.c:86:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:86:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:86:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:92:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:93:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:99:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:100:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:103:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:107:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:107:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:120:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:122:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:123:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:138:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:141:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:142:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:143:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:147:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:153:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:158:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:159:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:160:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:161:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:161:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:163:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:163:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:170:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:171:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:172:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:173:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:183:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:183:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:184:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:186:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:187:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:190:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:191:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:195:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:196:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:197:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:198:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:199:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:205:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:206:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:207:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:208:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:209:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:209:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:210:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:211:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:216:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:216:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:217:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:218:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:219:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:219:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:220:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:221:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:222:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:223:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:223:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:224:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:224:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:226:  An else should appear on the same line as the preceding }  [whitespace/newline] [4]
src/libvlc.c:227:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:229:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:229:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:232:  An else should appear on the same line as the preceding }  [whitespace/newline] [4]
src/libvlc.c:233:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:234:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:234:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:235:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:235:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:239:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:240:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:241:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:242:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:245:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:246:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:246:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:256:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:257:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:258:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:258:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:259:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:260:  Missing space before ( in for(  [whitespace/parens] [5]
src/libvlc.c:261:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:262:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:263:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:263:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:264:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:272:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:272:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:275:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:275:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:276:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:277:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:278:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:279:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:280:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:280:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:288:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:289:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:290:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:290:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:291:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:292:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:293:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:293:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:295:  An else should appear on the same line as the preceding }  [whitespace/newline] [4]
src/libvlc.c:296:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:296:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:296:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:297:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:297:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:301:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:301:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:301:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:303:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:304:  Missing space before ( in for(  [whitespace/parens] [5]
src/libvlc.c:305:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:307:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:307:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:308:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:313:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:314:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:314:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:316:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:316:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:317:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:318:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:319:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:319:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:326:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:327:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:329:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:330:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:331:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:331:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:333:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:333:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:337:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:337:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:338:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:338:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:341:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:341:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:342:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/libvlc.c:342:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:343:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:343:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:344:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:345:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:346:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:346:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:349:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:349:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:352:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:352:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:353:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:353:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:360:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/libvlc.c:362:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:364:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:364:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:369:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:369:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:377:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:377:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:378:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:378:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:381:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:381:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:384:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:384:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:387:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:387:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:390:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:390:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:391:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:391:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:394:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:394:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:399:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:399:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:400:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:401:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:402:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:402:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:403:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:404:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:405:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:405:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:406:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:406:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:407:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:407:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:408:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:408:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:409:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:409:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:410:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:410:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:413:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:413:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:417:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:417:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:418:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:419:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:420:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:420:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:421:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:422:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:422:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:424:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:424:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:430:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:430:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:431:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:431:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:433:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:434:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:436:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:437:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:438:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:438:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:442:  An else should appear on the same line as the preceding }  [whitespace/newline] [4]
src/libvlc.c:442:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:443:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:444:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:444:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:445:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:445:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:450:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:453:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:453:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:455:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:459:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:460:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:461:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:461:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:462:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:462:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:465:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:465:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:466:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:466:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:468:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:469:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:469:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:472:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:472:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:473:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:473:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:474:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:474:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:475:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:475:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:476:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:476:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:477:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:477:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:478:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:478:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:479:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:479:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:480:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:480:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:488:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:488:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:493:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:493:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:495:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:496:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:496:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:497:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:497:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:507:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:508:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:509:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:512:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:512:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:513:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:513:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:514:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:514:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:516:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:516:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:517:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:517:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:521:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:522:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:523:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:523:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:528:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:528:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:529:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:530:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:531:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:531:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:532:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:533:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:535:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:535:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:542:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:542:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:545:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:546:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:549:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:550:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.c:552:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:552:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:563:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:564:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:565:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:565:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:567:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:567:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:569:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:569:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:570:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:570:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:579:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:581:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:582:  Missing space before ( in while(  [whitespace/parens] [5]
src/libvlc.c:583:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:587:  Missing space before ( in while(  [whitespace/parens] [5]
src/libvlc.c:588:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:590:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:591:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:592:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:592:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:598:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:599:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:600:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:600:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:601:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:605:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:606:  Extra space after (  [whitespace/parens] [2]
src/libvlc.c:606:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:607:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:608:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:608:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:618:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.c:624:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:624:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:625:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:627:  Missing space before ( in if(  [whitespace/parens] [5]
src/libvlc.c:629:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.c:629:  Extra space before )  [whitespace/parens] [2]
src/libvlc.c:640:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:0:  No #ifndef header guard found, suggested CPP variable is: SAMPLES_VLC_SAMPLE_SRC_LIBVLC_H_  [build/header_guard] [5]
src/libvlc.h:34:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:35:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:40:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:40:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:40:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:41:  Extra space before [  [whitespace/braces] [5]
src/libvlc.h:41:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:41:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:41:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:45:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:45:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:58:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:58:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:60:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:62:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:66:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:68:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:68:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:84:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:86:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:90:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:90:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:91:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:91:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:111:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:123:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:124:  Missing space after ,  [whitespace/comma] [3]
src/libvlc.h:125:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:140:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:149:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/libvlc.h:150:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/libvlc.h:151:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/libvlc.h:152:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/libvlc.h:153:  At least two spaces is best between code and comments  [whitespace/comments] [2]
src/libvlc.h:159:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:160:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:161:  Using C-style cast.  Use reinterpret_cast<libvlc_priv_t *>(...) instead  [readability/casting] [4]
src/libvlc.h:166:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:166:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:168:  Extra space after ( in function call  [whitespace/parens] [4]
src/libvlc.h:168:  Extra space before )  [whitespace/parens] [2]
src/libvlc.h:173:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:179:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:185:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:191:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:200:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/libvlc.h:222:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:223:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:224:  Extra space before ( in function call  [whitespace/parens] [4]
src/libvlc.h:224:  Extra space before )  [whitespace/parens] [2]
src/missing.c:44:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:45:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:47:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:50:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:51:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:53:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:56:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:60:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:65:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:68:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:69:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:71:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:74:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:78:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:82:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:85:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:86:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:88:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:91:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:92:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:93:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:97:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:98:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:99:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:103:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:104:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:105:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:109:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:110:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:112:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:115:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:116:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:118:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:121:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:122:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:124:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:127:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:129:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:131:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:134:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:135:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:137:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:140:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:141:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:143:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:146:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:147:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:149:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:152:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:155:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:158:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:161:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:162:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:164:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:167:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:170:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:172:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:175:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:177:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:179:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:182:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:183:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:185:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:188:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:190:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:192:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:199:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:203:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:204:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:205:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:206:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:207:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:208:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:211:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:212:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:213:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:214:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:217:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:218:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:219:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:220:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:223:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:224:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:225:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:226:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:230:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:232:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:233:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:234:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:238:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:239:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:240:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:241:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:244:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:245:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:246:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:247:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:250:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:251:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:252:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:253:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:257:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:260:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:261:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:262:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:267:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:268:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:269:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:270:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:274:  Extra space after ( in function call  [whitespace/parens] [4]
src/missing.c:275:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:276:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:280:  Extra space after ( in function call  [whitespace/parens] [4]
src/missing.c:281:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:282:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:283:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:286:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:287:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:288:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:289:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:292:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:293:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:294:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:295:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:298:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/missing.c:298:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:299:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:300:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:301:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:304:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:306:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:307:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:308:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:311:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:312:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:313:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:314:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:317:  Extra space after ( in function call  [whitespace/parens] [4]
src/missing.c:318:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:319:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:320:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:323:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:324:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:325:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:326:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:329:  Lines should be <= 80 characters long  [whitespace/line_length] [2]
src/missing.c:329:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:332:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:333:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:334:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:335:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:338:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:341:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:342:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:343:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:351:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:352:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:353:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:354:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:355:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:358:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:359:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:360:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:361:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:364:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:365:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:366:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:367:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:368:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:369:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:372:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:373:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:374:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:375:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:376:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:379:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:380:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:381:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:382:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:385:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:386:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:387:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:391:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:392:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:393:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:394:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:399:  Extra space before ( in function call  [whitespace/parens] [4]
src/missing.c:400:  { should almost always be at the end of the previous line  [whitespace/braces] [4]
src/missing.c:401:  Extra space before ( in function call  [whitespace/parens] [4]

